<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Upgrade code for install
 *
 * @package   mod_viaassign
 * @copyright 2012 NetSpot {@link http://www.netspot.com.au}
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

/**
 * upgrade this viaassignment instance - this function could be skipped but it will be needed later
 * @param int $oldversion The old version of the viaassign module
 * @return bool
 */
defined('MOODLE_INTERNAL') || die();
function xmldb_viaassign_upgrade($oldversion) {
    global $CFG, $DB;

    $dbman = $DB->get_manager();
    
    if ($oldversion < 2018042002) {
        $table = new xmldb_table('viaassign_event');
        $table->add_field('id', XMLDB_TYPE_INTEGER, '10', XMLDB_UNSIGNED, XMLDB_NOTNULL, XMLDB_SEQUENCE, null);
        $table->add_field('eventid', XMLDB_TYPE_INTEGER, '10', XMLDB_UNSIGNED, XMLDB_NOTNULL, null, null, 'id');
        $table->add_field('viaid', XMLDB_TYPE_INTEGER, '10', XMLDB_UNSIGNED, XMLDB_NOTNULL, null, null, 'eventid');
        $table->add_field('viaassignid', XMLDB_TYPE_INTEGER, '10', XMLDB_UNSIGNED, XMLDB_NOTNULL, null, null, 'viaid');
        $table->add_field('timecreated', XMLDB_TYPE_INTEGER, '10', XMLDB_UNSIGNED, XMLDB_NOTNULL, null, null, 'viaassignid');
		
		$table->add_key('primary', XMLDB_KEY_PRIMARY, array('id'));
		$table->add_key('viaassign', XMLDB_KEY_FOREIGN, array('viaassignid'),array("viaassign"), array("id"));
		$table->add_key('via', XMLDB_KEY_FOREIGN, array('viaid'),array("via"), array("id"));
		$table->add_key('event', XMLDB_KEY_FOREIGN, array('eventid'),array("event"), array("id"));
        
        if (!$dbman->table_exists($table)) {
            $dbman->create_table($table);
        }
        
        $index = new xmldb_index('id', XMLDB_INDEX_UNIQUE, array('id'));
        $dbman->add_index($table, $index);
        
        upgrade_mod_savepoint(true, 2018042002, 'viaassign');
    }
    return true;
}